@@ -310,10 +310,10 @@ grn_dat_create(grn_ctx *ctx, const char *path, uint32_t,
       ctx->encoding : grn_gctx.encoding;
   dat->header->flags = flags;
   dat->header->encoding = encoding;
-  dat->header->tokenizer = 0;
+  dat->header->tokenizer = GRN_ID_NIL;
   dat->header->file_id = 0;
   dat->encoding = encoding;
-  dat->tokenizer = grn_ctx_at(ctx, dat->header->tokenizer);
+  dat->tokenizer = NULL;
   return dat;
 }
 
@@ -422,7 +422,9 @@ grn_id
 grn_dat_add(grn_ctx *ctx, grn_dat *dat, const void *key,
             unsigned int key_size, void **, int *added)
 {
-  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+  if (!key_size) {
+    return GRN_ID_NIL;
+  } else if (!grn_dat_open_trie_if_needed(ctx, dat)) {
     return GRN_ID_NIL;
   }
 
@@ -591,7 +593,9 @@ grn_rc
 grn_dat_update_by_id(grn_ctx *ctx, grn_dat *dat, grn_id src_key_id,
                      const void *dest_key, unsigned int dest_key_size)
 {
-  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+  if (!dest_key_size) {
+    return GRN_INVALID_ARGUMENT;
+  } else if (!grn_dat_open_trie_if_needed(ctx, dat)) {
     return ctx->rc;
   } else if (!dat->trie) {
     return GRN_INVALID_ARGUMENT;
@@ -624,7 +628,9 @@ grn_dat_update(grn_ctx *ctx, grn_dat *dat,
                const void *src_key, unsigned int src_key_size,
                const void *dest_key, unsigned int dest_key_size)
 {
-  if (!grn_dat_open_trie_if_needed(ctx, dat)) {
+  if (!dest_key_size) {
+    return GRN_INVALID_ARGUMENT;
+  } else if (!grn_dat_open_trie_if_needed(ctx, dat)) {
     return ctx->rc;
   } else if (!dat->trie) {
     return GRN_INVALID_ARGUMENT;
@@ -653,8 +659,8 @@ grn_dat_update(grn_ctx *ctx, grn_dat *dat,
 }
 
 int grn_dat_scan(grn_ctx *ctx, grn_dat *dat, const char *str,
-                 unsigned int str_size, grn_dat_scan_hit *scan_hits,
-                 unsigned int max_num_scan_hits, const char **str_rest) {
+                         unsigned int str_size, grn_dat_scan_hit *scan_hits,
+                         unsigned int max_num_scan_hits, const char **str_rest) {
   if (!grn_dat_open_trie_if_needed(ctx, dat) || !str ||
       !(dat->obj.header.flags & GRN_OBJ_KEY_VAR_SIZE) || !scan_hits) {
     return -1;
