@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef GROONGA_IN_H
@@ -375,7 +375,6 @@ typedef int grn_cond;
 #endif /* WIN32 */
 
 #ifdef __GNUC__
-
 # if (defined(__i386__) || defined(__x86_64__)) /* ATOMIC ADD */
 #  define GRN_ATOMIC_ADD_EX(p,i,r) \
   __asm__ __volatile__ ("lock; xaddl %0,%1" : "=r"(r), "=m"(*p) : "0"(i), "m" (*p))
@@ -414,6 +413,13 @@ typedef int grn_cond;
   (void)atomic_swap_64(p, v)
 # endif /* ATOMIC 64BIT SET */
 
+# ifdef HAVE_MKOSTEMP
+#  define GRN_MKOSTEMP mkostemp
+# else /* HAVE_MKOSTEMP */
+#  define GRN_MKOSTEMP(template,flags) \
+  (mktemp(template), open((template),flags))
+# endif /* HAVE_MKOSTEMP */
+
 #elif (defined(WIN32) || defined (_WIN64)) /* __GNUC__ */
 
 # define GRN_ATOMIC_ADD_EX(p,i,r) \
@@ -444,6 +450,9 @@ typedef int grn_cond;
 # define GRN_BIT_SCAN_REV(v,r)   for (r = 31; r && !((1 << r) & v); r--)
 # define GRN_BIT_SCAN_REV0 GRN_BIT_SCAN_REV
 
+# define GRN_MKOSTEMP(template,flags) \
+  (mktemp(template), open((template),((flags)|O_BINARY)))
+
 #else /* __GNUC__ */
 
 # if (defined(__sun) && defined(__SVR4)) /* ATOMIC ADD */
@@ -461,6 +470,10 @@ typedef int grn_cond;
 /* todo */
 # define GRN_BIT_SCAN_REV(v,r)   for (r = 31; r && !((1 << r) & v); r--)
 # define GRN_BIT_SCAN_REV0 GRN_BIT_SCAN_REV
+
+# define GRN_MKOSTEMP(template,flags) \
+  (mktemp(template), open((template),flags))
+
 #endif /* __GNUC__ */
 
 typedef uint8_t byte;
