@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "hash.h"
 #include "pat.h"
@@ -867,7 +867,7 @@ io_hash_init(grn_hash *ih, grn_ctx *ctx, const char *path, uint32_t key_size,
   header->max_offset = m - 1;
   header->n_entries = 0;
   header->n_garbages = 0;
-  header->tokenizer = 0;
+  header->tokenizer = GRN_ID_NIL;
   ih->obj.header.flags = flags;
   ih->ctx = ctx;
   ih->key_size = key_size;
@@ -880,7 +880,7 @@ io_hash_init(grn_hash *ih, grn_ctx *ctx, const char *path, uint32_t key_size,
   ih->io = io;
   ih->header = header;
   ih->lock = &header->lock;
-  ih->tokenizer = grn_ctx_at(ctx, header->tokenizer);
+  ih->tokenizer = NULL;
   return GRN_SUCCESS;
 }
 
