@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef GRN_HASH_H
 #define GRN_HASH_H
@@ -165,7 +165,7 @@ struct _grn_array_cursor {
 
 #define GRN_ARRAY_SIZE(array) (*((array)->n_entries))
 
-grn_rc grn_array_truncate(grn_ctx *ctx, grn_array *array);
+GRN_API grn_rc grn_array_truncate(grn_ctx *ctx, grn_array *array);
 grn_rc grn_array_copy_sort_key(grn_ctx *ctx, grn_array *array,
                                grn_table_sort_key *keys, int n_keys);
 
@@ -268,8 +268,8 @@ struct _grn_table_sort_optarg {
   int offset;
 };
 
-int grn_hash_sort(grn_ctx *ctx, grn_hash *hash, int limit,
-                  grn_array *result, grn_table_sort_optarg *optarg);
+GRN_API int grn_hash_sort(grn_ctx *ctx, grn_hash *hash, int limit,
+                          grn_array *result, grn_table_sort_optarg *optarg);
 
 grn_rc grn_hash_lock(grn_ctx *ctx, grn_hash *hash, int timeout);
 grn_rc grn_hash_unlock(grn_ctx *ctx, grn_hash *hash);
