@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef GRN_II_H
 #define GRN_II_H
@@ -39,8 +39,6 @@
 extern "C" {
 #endif
 
-typedef struct _grn_ii grn_ii;
-
 struct _grn_ii {
   grn_db_obj obj;
   grn_io *seg;
@@ -100,10 +98,11 @@ struct _grn_ii_updspec {
 
 typedef struct _grn_ii_updspec grn_ii_updspec;
 
-grn_ii *grn_ii_create(grn_ctx *ctx, const char *path, grn_obj *lexicon, uint32_t flags);
-grn_ii *grn_ii_open(grn_ctx *ctx, const char *path, grn_obj *lexicon);
-grn_rc grn_ii_close(grn_ctx *ctx, grn_ii *ii);
-grn_rc grn_ii_remove(grn_ctx *ctx, const char *path);
+GRN_API grn_ii *grn_ii_create(grn_ctx *ctx, const char *path, grn_obj *lexicon,
+                              uint32_t flags);
+GRN_API grn_ii *grn_ii_open(grn_ctx *ctx, const char *path, grn_obj *lexicon);
+GRN_API grn_rc grn_ii_close(grn_ctx *ctx, grn_ii *ii);
+GRN_API grn_rc grn_ii_remove(grn_ctx *ctx, const char *path);
 grn_rc grn_ii_info(grn_ctx *ctx, grn_ii *ii, uint64_t *seg_size, uint64_t *chunk_size);
 grn_rc grn_ii_update_one(grn_ctx *ctx, grn_ii *ii, uint32_t key, grn_ii_updspec *u,
                          grn_hash *h);
@@ -168,8 +167,9 @@ struct _grn_select_optarg {
   int max_size;
 };
 
-grn_rc grn_ii_column_update(grn_ctx *ctx, grn_ii *ii, grn_id id, unsigned int section,
-                            grn_obj *oldvalue, grn_obj *newvalue, grn_obj *posting);
+GRN_API grn_rc grn_ii_column_update(grn_ctx *ctx, grn_ii *ii, grn_id id,
+                                    unsigned int section, grn_obj *oldvalue,
+                                    grn_obj *newvalue, grn_obj *posting);
 grn_rc grn_ii_term_extract(grn_ctx *ctx, grn_ii *ii, const char *string,
                             unsigned int string_len, grn_hash *s,
                             grn_operator op, grn_select_optarg *optarg);
@@ -180,11 +180,6 @@ GRN_API grn_rc grn_ii_select(grn_ctx *ctx, grn_ii *ii, const char *string, unsig
 grn_rc grn_ii_sel(grn_ctx *ctx, grn_ii *ii, const char *string, unsigned int string_len,
                   grn_hash *s, grn_operator op, grn_search_optarg *optarg);
 
-grn_rc grn_ii_query_select(grn_ctx *ctx, grn_ii *i, grn_query *q, grn_hash *r, grn_operator op);
-
-grn_rc grn_query_search(grn_ctx *ctx, grn_ii *i, grn_query *q,
-                        grn_hash *r, grn_operator op);
-
 void grn_ii_resolve_sel_and(grn_ctx *ctx, grn_hash *s, grn_operator op);
 
 grn_rc grn_ii_at(grn_ctx *ctx, grn_ii *ii, grn_id id, grn_hash *s, grn_operator op);
@@ -192,7 +187,7 @@ grn_rc grn_ii_at(grn_ctx *ctx, grn_ii *ii, grn_id id, grn_hash *s, grn_operator
 void grn_ii_inspect_elements(grn_ctx *ctx, grn_ii *ii, grn_obj *buf);
 void grn_ii_cursor_inspect(grn_ctx *ctx, grn_ii_cursor *c, grn_obj *buf);
 
-grn_rc grn_ii_build(grn_ctx *ctx, grn_ii *ii);
+grn_rc grn_ii_build(grn_ctx *ctx, grn_ii *ii, uint64_t sparsity);
 
 #ifdef __cplusplus
 }
