@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef GRN_PAT_H
 #define GRN_PAT_H
@@ -38,6 +38,8 @@ struct _grn_pat {
   uint32_t key_size;
   uint32_t value_size;
   grn_obj *tokenizer;
+  grn_id *cache;
+  uint32_t cache_size;
 };
 
 #define GRN_PAT_NDELINFOS 0x100
@@ -87,18 +89,21 @@ struct _grn_pat_cursor {
   uint8_t curr_key[GRN_TABLE_MAX_KEY_SIZE];
 };
 
-grn_id grn_pat_curr_id(grn_ctx *ctx, grn_pat *pat);
+GRN_API grn_id grn_pat_curr_id(grn_ctx *ctx, grn_pat *pat);
 
 /* private */
-grn_rc grn_pat_truncate(grn_ctx *ctx, grn_pat *pat);
+GRN_API grn_rc grn_pat_truncate(grn_ctx *ctx, grn_pat *pat);
 const char *_grn_pat_key(grn_ctx *ctx, grn_pat *pat, grn_id id, uint32_t *key_size);
 grn_id grn_pat_next(grn_ctx *ctx, grn_pat *pat, grn_id id);
 const char *grn_pat_get_value_(grn_ctx *ctx, grn_pat *pat, grn_id id, uint32_t *size);
-grn_id grn_pat_at(grn_ctx *ctx, grn_pat *pat, grn_id id);
+GRN_API grn_id grn_pat_at(grn_ctx *ctx, grn_pat *pat, grn_id id);
 void grn_pat_check(grn_ctx *ctx, grn_pat *pat);
 void grn_pat_inspect_nodes(grn_ctx *ctx, grn_pat *pat, grn_obj *buf);
 void grn_pat_cursor_inspect(grn_ctx *ctx, grn_pat_cursor *c, grn_obj *buf);
 
+grn_rc grn_pat_cache_enable(grn_ctx *ctx, grn_pat *pat, uint32_t cache_size);
+grn_rc grn_pat_cache_disable(grn_ctx *ctx, grn_pat *pat);
+
 #ifdef __cplusplus
 }
 #endif
