@@ -12,12 +12,12 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "groonga_in.h"
 #include "str.h"
 #include "store.h"
-#include "ql.h"
+#include "ctx_impl.h"
 #include "output.h"
 #include <string.h>
 
