@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef GRN_STR_H
 #define GRN_STR_H
@@ -66,7 +66,7 @@ GRN_API grn_rc grn_aton(grn_ctx *ctx, const char *p, const char *end, const char
 GRN_API const char *grn_enctostr(grn_encoding enc);
 grn_encoding grn_strtoenc(const char *str);
 
-void grn_itoh(unsigned int i, char *p, unsigned int len);
+GRN_API void grn_itoh(unsigned int i, char *p, unsigned int len);
 int grn_str_tok(const char *str, size_t str_len, char delim, const char **tokbuf, int buf_size, const char **rest);
 GRN_API int grn_str_getopt(int argc, char * const argv[], const grn_str_getopt_opt *opts, int *flags);
 
@@ -112,8 +112,9 @@ GRN_API const char *grn_text_unesc_tok(grn_ctx *ctx, grn_obj *buf,
                                        const char *p, const char *e,
                                        char *tok_type);
 
-void grn_str_url_path_normalize(grn_ctx *ctx, const char *path, size_t path_len,
-                                char *buf, size_t buf_len);
+GRN_API void grn_str_url_path_normalize(grn_ctx *ctx,
+                                        const char *path, size_t path_len,
+                                        char *buf, size_t buf_len);
 
 GRN_API grn_rc grn_text_otoxml(grn_ctx *ctx, grn_obj *bulk, grn_obj *obj,
                                 grn_obj_format *format);
