@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2010-2011 Brazil
+/* Copyright(C) 2010-2012 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -168,9 +168,9 @@ output(grn_ctx *ctx, grn_obj *table, grn_obj *res, grn_id tid,
     grn_obj_format format;
     grn_table_sort_key *keys;
     const char *sortby_val = GRN_TEXT_VALUE(sortby);
-    unsigned sortby_len = GRN_TEXT_LEN(sortby);
+    unsigned int sortby_len = GRN_TEXT_LEN(sortby);
     const char *oc_val = GRN_TEXT_VALUE(output_columns);
-    unsigned oc_len = GRN_TEXT_LEN(output_columns);
+    unsigned int oc_len = GRN_TEXT_LEN(output_columns);
     if (!sortby_val || !sortby_len) {
       sortby_val = DEFAULT_SORTBY;
       sortby_len = sizeof(DEFAULT_SORTBY) - 1;
@@ -238,39 +238,37 @@ complete(grn_ctx *ctx, grn_obj *items, grn_obj *items_boost, grn_obj *col,
   if ((res = grn_table_create(ctx, NULL, 0, NULL,
                               GRN_TABLE_HASH_KEY|GRN_OBJ_WITH_SUBREC, items, NULL))) {
     grn_id tid = grn_table_get(ctx, items, TEXT_VALUE_LEN(query));
-    if (GRN_TEXT_LEN(query)) {
-      grn_str *norm;
+    grn_str *norm;
+    if (GRN_TEXT_LEN(query) &&
+        (norm = grn_str_open(ctx, TEXT_VALUE_LEN(query), GRN_STR_NORMALIZE))) {
       grn_table_cursor *cur;
-      if ((norm = grn_str_open(ctx, TEXT_VALUE_LEN(query), GRN_STR_NORMALIZE))) {
-        /* RK search + prefix search */
-        grn_obj *index;
-        /* FIXME: support index selection */
-        if (grn_column_index(ctx, col, GRN_OP_PREFIX, &index, 1, NULL)) {
-          if ((cur = grn_table_cursor_open(ctx, grn_ctx_at(ctx, index->header.domain),
-                                           norm->norm, norm->norm_blen, NULL, 0, 0, -1,
-                                           GRN_CURSOR_PREFIX|GRN_CURSOR_RK))) {
-            grn_id id;
-            while ((id = grn_table_cursor_next(ctx, cur))) {
-              grn_ii_cursor *icur;
-              if ((icur = grn_ii_cursor_open(ctx, (grn_ii *)index, id,
-                                             GRN_ID_NIL, GRN_ID_MAX, 1, 0))) {
-                grn_ii_posting *p;
-                while ((p = grn_ii_cursor_next(ctx, icur))) {
-                  complete_add_item(ctx, p->rid, res, frequency_threshold,
-                                    items_freq, items_boost,
-                                    &item_freq, &item_boost);
-                }
-                grn_ii_cursor_close(ctx, icur);
+      /* RK search + prefix search */
+      grn_obj *index;
+      /* FIXME: support index selection */
+      if (grn_column_index(ctx, col, GRN_OP_PREFIX, &index, 1, NULL)) {
+        if ((cur = grn_table_cursor_open(ctx, grn_ctx_at(ctx, index->header.domain),
+                                         norm->norm, norm->norm_blen, NULL, 0, 0, -1,
+                                         GRN_CURSOR_PREFIX|GRN_CURSOR_RK))) {
+          grn_id id;
+          while ((id = grn_table_cursor_next(ctx, cur))) {
+            grn_ii_cursor *icur;
+            if ((icur = grn_ii_cursor_open(ctx, (grn_ii *)index, id,
+                                           GRN_ID_NIL, GRN_ID_MAX, 1, 0))) {
+              grn_ii_posting *p;
+              while ((p = grn_ii_cursor_next(ctx, icur))) {
+                complete_add_item(ctx, p->rid, res, frequency_threshold,
+                                  items_freq, items_boost,
+                                  &item_freq, &item_boost);
               }
+              grn_ii_cursor_close(ctx, icur);
             }
-            grn_table_cursor_close(ctx, cur);
-          } else {
-            ERR(GRN_UNKNOWN_ERROR, "cannot open cursor for prefix RK search.");
           }
+          grn_table_cursor_close(ctx, cur);
         } else {
-          ERR(GRN_UNKNOWN_ERROR, "cannot find index for prefix RK search.");
+          ERR(GRN_UNKNOWN_ERROR, "cannot open cursor for prefix RK search.");
         }
-        grn_str_close(ctx, norm);
+      } else {
+        ERR(GRN_UNKNOWN_ERROR, "cannot find index for prefix RK search.");
       }
       cooccurrence_search(ctx, items, items_boost, tid, res, COMPLETE,
                           frequency_threshold,
@@ -278,7 +276,7 @@ complete(grn_ctx *ctx, grn_obj *items, grn_obj *items_boost, grn_obj *col,
       if (((prefix_search_mode == GRN_SUGGEST_PREFIX_SEARCH_YES) ||
            (prefix_search_mode == GRN_SUGGEST_PREFIX_SEARCH_AUTO &&
             !grn_table_size(ctx, res))) &&
-          (cur = grn_table_cursor_open(ctx, items, TEXT_VALUE_LEN(query),
+          (cur = grn_table_cursor_open(ctx, items, norm->norm, norm->norm_blen,
                                        NULL, 0, 0, -1, GRN_CURSOR_PREFIX))) {
         grn_id id;
         while ((id = grn_table_cursor_next(ctx, cur))) {
@@ -287,6 +285,7 @@ complete(grn_ctx *ctx, grn_obj *items, grn_obj *items_boost, grn_obj *col,
         }
         grn_table_cursor_close(ctx, cur);
       }
+      grn_str_close(ctx, norm);
     }
     output(ctx, items, res, tid, sortby, output_columns, offset, limit);
     grn_obj_close(ctx, res);
