@@ -21,9 +21,12 @@
 #include <event.h>
 #include <stdint.h>
 
+#include <groonga.h>
+
 int print_error(const char *format, ...);
 int daemonize(void);
-void parse_keyval(struct evkeyvalq *get_args,
+void parse_keyval(grn_ctx *ctx,
+                  struct evkeyvalq *get_args,
                   const char **query, const char **types,
                   const char **client_id, const char **target_name,
                   const char **learn_target_name,
@@ -31,6 +34,7 @@ void parse_keyval(struct evkeyvalq *get_args,
                   uint64_t *millisec,
                   int *frequency_threshold,
                   double *conditional_probability_threshold,
-                  int *limit);
+                  int *limit,
+                  grn_obj *pass_through_parameters);
 
 #endif /* GRN_SUGGEST_UTIL_H */
