@@ -36,7 +36,8 @@
 
 namespace
 {
-  void create_key(std::string *key, std::size_t min_length, std::size_t max_length)
+  void create_key(std::string *key, std::size_t min_length,
+                  std::size_t max_length)
   {
     key->resize(min_length + (std::rand() % (max_length - min_length + 1)));
     for (std::size_t i = 0; i < key->size(); ++i) {
@@ -93,12 +94,13 @@ namespace test_dat_pat
     std::sprintf(path, "%s/%s.dat", base_dir, filename);
   }
 
-  grn_pat *create_pat(const char *filename, const std::vector<std::string> &keys)
+  grn_pat *create_pat(const char *filename,
+                      const std::vector<std::string> &keys)
   {
     char pat_path[PATH_MAX];
     generate_pat_path(filename, pat_path);
-    grn_pat * const pat = grn_pat_create(&ctx, pat_path,
-                                         1024, 0, GRN_OBJ_KEY_VAR_SIZE);
+    grn_pat * const pat =
+        grn_pat_create(&ctx, pat_path, 1024, 0, GRN_OBJ_KEY_VAR_SIZE);
     cppcut_assert_not_null(pat);
 
     for (std::size_t i = 0; i < keys.size(); ++i) {
@@ -107,12 +109,13 @@ namespace test_dat_pat
     return pat;
   }
 
-  grn_dat *create_dat(const char *filename, const std::vector<std::string> &keys)
+  grn_dat *create_dat(const char *filename,
+                      const std::vector<std::string> &keys)
   {
     char dat_path[PATH_MAX];
     generate_dat_path(filename, dat_path);
-    grn_dat * const dat = grn_dat_create(&ctx, dat_path,
-                                         1024, 0, GRN_OBJ_KEY_VAR_SIZE);
+    grn_dat * const dat =
+        grn_dat_create(&ctx, dat_path, 1024, 0, GRN_OBJ_KEY_VAR_SIZE);
     cppcut_assert_not_null(dat);
 
     for (std::size_t i = 0; i < keys.size(); ++i) {
@@ -145,8 +148,8 @@ namespace test_dat_pat
     pat = create_pat(filename, keys);
     dat = create_dat(filename, keys);
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
 
     cut_assert_exist_path(pat_path);
     cut_assert_exist_path(dat_path);
@@ -157,8 +160,8 @@ namespace test_dat_pat
     cppcut_assert_not_null(pat);
     cppcut_assert_not_null(dat);
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_remove(void)
@@ -169,8 +172,8 @@ namespace test_dat_pat
     grn_pat * const pat = create_pat(filename, keys);
     grn_dat * const dat = create_dat(filename, keys);
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
 
     char pat_path[PATH_MAX];
     char dat_path[PATH_MAX];
@@ -204,20 +207,24 @@ namespace test_dat_pat
     for (int i = 0; i < 1000; ++i) {
       create_key(&key, 3, 5);
 
-      const grn_id pat_id = grn_pat_get(&ctx, pat, key.c_str(), key.length(), NULL);
-      const grn_id dat_id = grn_dat_get(&ctx, dat, key.c_str(), key.length(), NULL);
+      const grn_id pat_id =
+          grn_pat_get(&ctx, pat, key.c_str(), key.length(), NULL);
+      const grn_id dat_id =
+          grn_dat_get(&ctx, dat, key.c_str(), key.length(), NULL);
       cppcut_assert_equal(pat_id, dat_id);
       if (pat_id != GRN_ID_NIL) {
         char pat_key[1024];
-        int pat_length = grn_pat_get_key(&ctx, pat, pat_id, pat_key, sizeof(pat_key));
+        const int pat_length =
+            grn_pat_get_key(&ctx, pat, pat_id, pat_key, sizeof(pat_key));
         char dat_key[1024];
-        int dat_length = grn_dat_get_key(&ctx, dat, dat_id, dat_key, sizeof(dat_key));
+        const int dat_length =
+            grn_dat_get_key(&ctx, dat, dat_id, dat_key, sizeof(dat_key));
         cut_assert_equal_memory(pat_key, pat_length, dat_key, dat_length);
       }
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_add(void)
@@ -233,108 +240,176 @@ namespace test_dat_pat
     for (int i = 0; i < 1000; ++i) {
       create_key(&key, 3, 5);
       int pat_added = -1;
-      const grn_id pat_id = grn_pat_add(&ctx, pat, key.c_str(),
-                                        key.length(), NULL, &pat_added);
+      const grn_id pat_id =
+          grn_pat_add(&ctx, pat, key.c_str(), key.length(), NULL, &pat_added);
       int dat_added = -2;
-      const grn_id dat_id = grn_dat_add(&ctx, dat, key.c_str(),
-                                        key.length(), NULL, &dat_added);
+      const grn_id dat_id =
+          grn_dat_add(&ctx, dat, key.c_str(), key.length(), NULL, &dat_added);
       cppcut_assert_equal(pat_id, dat_id);
       cppcut_assert_equal(pat_added, dat_added);
 
-      cppcut_assert_equal(grn_pat_size(&ctx, pat), grn_dat_size(&ctx, dat));
-      cppcut_assert_equal(grn_pat_curr_id(&ctx, pat), grn_dat_curr_id(&ctx, dat));
+      cppcut_assert_equal(grn_pat_size(&ctx, pat),
+                          grn_dat_size(&ctx, dat));
+      cppcut_assert_equal(grn_pat_curr_id(&ctx, pat),
+                          grn_dat_curr_id(&ctx, dat));
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_delete_by_id(void)
   {
     const char * const filename = "test_delete_by_id";
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete_by_id(&ctx, NULL, 1, NULL));
-//    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-//                        grn_dat_delete_by_id(&ctx, NULL, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_pat_delete_by_id(&ctx, NULL, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_dat_delete_by_id(&ctx, NULL, 1, NULL));
 
     std::vector<std::string> keys;
     create_keys(&keys, 1000, 3, 5);
     grn_pat * const pat = create_pat(filename, keys);
     grn_dat * const dat = create_dat(filename, keys);
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete_by_id(&ctx, pat, GRN_ID_NIL, NULL));
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_dat_delete_by_id(&ctx, dat, GRN_ID_NIL, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+        grn_pat_delete_by_id(&ctx, pat, GRN_ID_NIL, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+        grn_dat_delete_by_id(&ctx, dat, GRN_ID_NIL, NULL));
 
     for (std::size_t i = 0; i < keys.size(); i += 2) {
       const grn_id key_id = static_cast<grn_id>(i + 1);
-      cppcut_assert_equal(GRN_SUCCESS,
-                          grn_pat_delete_by_id(&ctx, pat, key_id, NULL));
-      cppcut_assert_equal(GRN_SUCCESS,
-                          grn_dat_delete_by_id(&ctx, dat, key_id, NULL));
+      grn_test_assert_equal_rc(GRN_SUCCESS,
+                               grn_pat_delete_by_id(&ctx, pat, key_id, NULL));
+      grn_test_assert_equal_rc(GRN_SUCCESS,
+                               grn_dat_delete_by_id(&ctx, dat, key_id, NULL));
     }
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete_by_id(&ctx, pat, 1, NULL));
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_dat_delete_by_id(&ctx, dat, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_pat_delete_by_id(&ctx, pat, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_dat_delete_by_id(&ctx, dat, 1, NULL));
 
     for (std::size_t i = 0; i < keys.size(); ++i) {
       const grn_id key_id = static_cast<grn_id>(i + 1);
       const grn_rc rc = (i & 1) ? GRN_SUCCESS : GRN_INVALID_ARGUMENT;
-      cppcut_assert_equal(rc, grn_pat_delete_by_id(&ctx, pat, key_id, NULL));
-      cppcut_assert_equal(rc, grn_dat_delete_by_id(&ctx, dat, key_id, NULL));
+      grn_test_assert_equal_rc(rc,
+          grn_pat_delete_by_id(&ctx, pat, key_id, NULL));
+      grn_test_assert_equal_rc(rc,
+          grn_dat_delete_by_id(&ctx, dat, key_id, NULL));
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_delete(void)
   {
     const char * const filename = "test_delete";
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete(&ctx, NULL, "XYZ", 3, NULL));
-//    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-//                        grn_dat_delete(&ctx, NULL, "XYZ", 3, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_pat_delete(&ctx, NULL, "XYZ", 3, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_dat_delete(&ctx, NULL, "XYZ", 3, NULL));
 
     std::vector<std::string> keys;
     create_keys(&keys, 1000, 3, 5);
     grn_pat * const pat = create_pat(filename, keys);
     grn_dat * const dat = create_dat(filename, keys);
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete(&ctx, pat, NULL, 1, NULL));
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_dat_delete(&ctx, dat, NULL, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_pat_delete(&ctx, pat, NULL, 1, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_dat_delete(&ctx, dat, NULL, 1, NULL));
 
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_pat_delete(&ctx, pat, "XYZ", 0, NULL));
-    cppcut_assert_equal(GRN_INVALID_ARGUMENT,
-                        grn_dat_delete(&ctx, dat, "XYZ", 0, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_pat_delete(&ctx, pat, "XYZ", 0, NULL));
+    grn_test_assert_equal_rc(GRN_INVALID_ARGUMENT,
+                             grn_dat_delete(&ctx, dat, "XYZ", 0, NULL));
 
     for (std::size_t i = 0; i < keys.size(); i += 2) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
-      cppcut_assert_equal(GRN_SUCCESS,
-                          grn_pat_delete(&ctx, pat, ptr, length, NULL));
-      cppcut_assert_equal(GRN_SUCCESS,
-                          grn_dat_delete(&ctx, dat, ptr, length, NULL));
+      grn_test_assert_equal_rc(GRN_SUCCESS,
+                               grn_pat_delete(&ctx, pat, ptr, length, NULL));
+      grn_test_assert_equal_rc(GRN_SUCCESS,
+                               grn_dat_delete(&ctx, dat, ptr, length, NULL));
     }
 
     for (std::size_t i = 0; i < keys.size(); ++i) {
       const char * const ptr = keys[i].c_str();
       const uint32_t length = static_cast<uint32_t>(keys[i].length());
       const grn_rc rc = (i & 1) ? GRN_SUCCESS : GRN_INVALID_ARGUMENT;
-      cppcut_assert_equal(rc, grn_pat_delete(&ctx, pat, ptr, length, NULL));
-      cppcut_assert_equal(rc, grn_dat_delete(&ctx, dat, ptr, length, NULL));
+      grn_test_assert_equal_rc(rc,
+          grn_pat_delete(&ctx, pat, ptr, length, NULL));
+      grn_test_assert_equal_rc(rc,
+          grn_dat_delete(&ctx, dat, ptr, length, NULL));
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+  }
+
+  void test_scan(void)
+  {
+    const char * const filename = "test_scan";
+
+    std::vector<std::string> keys;
+    create_keys(&keys, 1000, 3, 5);
+    grn_pat * const pat = create_pat(filename, keys);
+    grn_dat * const dat = create_dat(filename, keys);
+
+    std::string query;
+    for (int i = 0; i < 1000; ++i) {
+      create_key(&query, 8, 16);
+
+      grn_pat_scan_hit pat_hits[4];
+      const char *pat_rest;
+      const int pat_num_hits =
+          grn_pat_scan(&ctx, pat, query.c_str(), query.length(),
+                       pat_hits, 4, &pat_rest);
+
+      grn_dat_scan_hit dat_hits[4];
+      const char *dat_rest;
+      const int dat_num_hits =
+          grn_dat_scan(&ctx, dat, query.c_str(), query.length(),
+                       dat_hits, 4, &dat_rest);
+
+      cppcut_assert_equal(pat_num_hits, dat_num_hits);
+      for (int j = 0; j < pat_num_hits; ++j) {
+        cppcut_assert_equal(pat_hits[j].id, dat_hits[j].id);
+        cppcut_assert_equal(pat_hits[j].offset, dat_hits[j].offset);
+        cppcut_assert_equal(pat_hits[j].length, dat_hits[j].length);
+      }
+      cppcut_assert_equal(pat_rest, dat_rest);
+    }
+
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+  }
+
+  void test_lcp_search(void)
+  {
+    const char * const filename = "test_lcp_search";
+
+    std::vector<std::string> keys;
+    create_keys(&keys, 1000, 3, 5);
+    grn_pat * const pat = create_pat(filename, keys);
+    grn_dat * const dat = create_dat(filename, keys);
+
+    std::string query;
+    for (int i = 0; i < 1000; ++i) {
+      create_key(&query, 3, 6);
+
+      const grn_id pat_id =
+          grn_pat_lcp_search(&ctx, pat, query.c_str(), query.length());
+      const grn_id dat_id =
+          grn_dat_lcp_search(&ctx, dat, query.c_str(), query.length());
+      cppcut_assert_equal(pat_id, dat_id);
+    }
+
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_id_cursor(void)
@@ -363,10 +438,12 @@ namespace test_dat_pat
 
       const char * const min_key =
           (min_id != GRN_ID_NIL) ? keys[min_id - 1].c_str() : NULL;
-      const int min_length = min_key ? static_cast<int>(keys[min_id - 1].length()) : 0;
+      const int min_length =
+          min_key ? static_cast<int>(keys[min_id - 1].length()) : 0;
       const char * const max_key =
           (max_id != GRN_ID_NIL) ? keys[max_id - 1].c_str() : NULL;
-      const int max_length = max_key ? static_cast<int>(keys[max_id - 1].length()) : 0;
+      const int max_length =
+          max_key ? static_cast<int>(keys[max_id - 1].length()) : 0;
 
       const int temp = std::rand();
       const int offset = temp & 0x0F;
@@ -377,14 +454,14 @@ namespace test_dat_pat
           (((temp & 0x400) == 0x400) ?
               GRN_CURSOR_DESCENDING : GRN_CURSOR_ASCENDING);
 
-      grn_pat_cursor * const pat_cursor =
-          grn_pat_cursor_open(&ctx, pat, min_key, min_length, max_key, max_length,
-                              offset, limit, flags);
+      grn_pat_cursor * const pat_cursor = grn_pat_cursor_open(
+          &ctx, pat, min_key, min_length, max_key, max_length,
+          offset, limit, flags);
       cppcut_assert_not_null(pat_cursor);
 
-      grn_dat_cursor * const dat_cursor =
-          grn_dat_cursor_open(&ctx, dat, min_key, min_length, max_key, max_length,
-                              offset, limit, flags);
+      grn_dat_cursor * const dat_cursor = grn_dat_cursor_open(
+          &ctx, dat, min_key, min_length, max_key, max_length,
+          offset, limit, flags);
       cppcut_assert_not_null(dat_cursor);
 
       grn_id pat_id;
@@ -399,8 +476,8 @@ namespace test_dat_pat
       grn_dat_cursor_close(&ctx, dat_cursor);
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_key_cursor(void)
@@ -461,8 +538,8 @@ namespace test_dat_pat
       grn_dat_cursor_close(&ctx, dat_cursor);
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_prefix_cursor(void)
@@ -511,8 +588,8 @@ namespace test_dat_pat
       grn_dat_cursor_close(&ctx, dat_cursor);
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_predictive_cursor(void)
@@ -559,8 +636,8 @@ namespace test_dat_pat
       grn_dat_cursor_close(&ctx, dat_cursor);
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 
   void test_truncate(void)
@@ -572,8 +649,8 @@ namespace test_dat_pat
     grn_pat * const pat = create_pat(filename, keys);
     grn_dat * const dat = create_dat(filename, keys);
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_truncate(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_truncate(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_truncate(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_truncate(&ctx, dat));
 
     cppcut_assert_equal(static_cast<unsigned int>(0), grn_pat_size(&ctx, pat));
     cppcut_assert_equal(static_cast<unsigned int>(0), grn_dat_size(&ctx, dat));
@@ -587,7 +664,7 @@ namespace test_dat_pat
                           grn_dat_get(&ctx, dat, ptr, length, NULL));
     }
 
-    cppcut_assert_equal(GRN_SUCCESS, grn_pat_close(&ctx, pat));
-    cppcut_assert_equal(GRN_SUCCESS, grn_dat_close(&ctx, dat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_pat_close(&ctx, pat));
+    grn_test_assert_equal_rc(GRN_SUCCESS, grn_dat_close(&ctx, dat));
   }
 }
