@@ -13,13 +13,14 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include "grn-assertions.h"
 #include <str.h>
 #include <db.h>
 
+#include "grn-assertions.h"
+
 const gchar *
 grn_rc_to_string(grn_rc rc)
 {
@@ -651,6 +652,7 @@ grn_test_send_command(grn_ctx *context, const gchar *command)
   unsigned int send_id, receive_id;
   GString *result;
   const gchar **lines;
+  const gchar *taken_result;
 
   result = g_string_new(NULL);
   lines = cut_take_string_array(g_strsplit(command, "\n", 0));
@@ -671,7 +673,9 @@ grn_test_send_command(grn_ctx *context, const gchar *command)
                             cut_message("<%s>:<%s>", command, result->str));
   }
 
-  return cut_take_strdup(g_string_free(result, FALSE));
+  taken_result = cut_take_strdup(result->str);
+  g_string_free(result, TRUE);
+  return taken_result;
 }
 
 void
